<?php
/**
 * 发送帖子内容的API接口
 * 功能：接收前端POST请求，将帖子内容存入数据库
 * 请求方式：POST
 * 请求体格式：JSON
 * 返回格式：JSON
 */

// 启动会话 - 用于后续可能的用户认证扩展
session_start();

// 初始化响应数组 - 统一接口返回格式
$response = [
    'success' => false,    // 操作是否成功标志位
    'message' => '未知错误', // 返回给客户端的消息
];

/**
 * 数据库连接配置
 * 注意：实际生产环境中应使用环境变量或配置文件存储敏感信息
 */
$servername = "127.0.0.1:3306";  // MySQL服务器地址和端口
$username = "root";             // 数据库用户名
$passwd = "kali";               // 数据库密码
$database = "rucwall";          // 数据库名称

// 创建MySQLi数据库连接对象
$conn = new mysqli($servername, $username, $passwd, $database);

// 检查数据库连接是否成功
if ($conn->connect_error) {
    http_response_code(500); // 设置HTTP状态码为500(服务器内部错误)
    $response['message'] = '数据库连接失败';
    echo json_encode($response); // 返回JSON格式的错误信息
    die(); // 终止脚本执行
}

// 验证请求方法是否为POST
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405); // 405 Method Not Allowed
    die('只允许POST请求'); // 直接返回文本错误信息
}

/**
 * 处理请求体数据
 */
$json_data = file_get_contents('php://input'); // 从输入流获取原始JSON数据
if (empty($json_data)) {
    http_response_code(400); // 400 Bad Request
    die('请求体不能为空');
}

// 解析JSON数据为关联数组
$data = json_decode($json_data, true);
if (json_last_error() !== JSON_ERROR_NONE) {
    http_response_code(400);
    $response['message'] = '无效的JSON格式';
    echo json_encode($response);
    die();
}

// 验证必须字段content是否存在且不为空
if (!isset($data['content']) || empty(trim($data['content']))) {
    http_response_code(400);
    $response['message'] = 'content字段不能为空';
    echo json_encode($response);
    die();
}

// 去除content字段两端的空白字符
$content = trim($data['content']);

/**
 * 数据库操作部分
 * 使用预处理语句防止SQL注入
 */
$sql = "INSERT INTO posts (content) VALUES (?)"; // 参数化查询SQL

$stmt = $conn->prepare($sql); // 预处理SQL语句
$stmt->bind_param("s", $content); // 绑定参数(s表示字符串类型)

// 执行SQL语句
$res = $stmt->execute();

// 处理执行结果
if($res) {
    // 发布成功
    $response['success'] = true;
    $response['message'] = '发布成功';
} else {
    // 发布失败
    http_response_code(500);
    $response['message'] = '发布失败';
}

// 返回JSON格式的响应
echo json_encode($response);

// 注意：脚本结束时会自动关闭数据库连接