// ===== 功能提示相关 =====
// 未开发功能的提示函数 - 当用户点击未完成的功能时，显示提示信息
function undevelopAlert() {
    alert("该功能正在开发中，请耐心等待...");
}

// 获取添加图片按钮元素，并添加点击事件监听器
const addImgBtn = document.getElementById("add_img_btn")
addImgBtn.addEventListener("click", undevelopAlert)

// 获取搜索表单元素，并添加提交事件监听器
const searchForm = document.getElementById("search_form")
searchForm.addEventListener("submit", function(event) {
    // 阻止表单的默认提交行为，改为执行我们自定义的动作
    event.preventDefault(); 
    // 展示未开发的提示
    undevelopAlert();
})

// ===== 帖子管理相关 =====
/**
 * 创建新帖子的函数
 * @param {string} postId - 帖子的唯一标识ID
 * @param {string} timeText - 发帖时间描述（例如："1分钟之前"）
 * @param {string} content - 帖子的具体内容
 * @param {number} likes - 点赞数量
 * @param {number} messages - 评论数量
 */
function createPostContainer(postId, timeText, content, likes, messages) {
    // 创建最外层的帖子容器div
    const postContainer = document.createElement('div');
    postContainer.className = 'post_container';
    
    // 创建帖子头部区域（包含帖子ID和发布时间）
    const postHeader = document.createElement('div');
    postHeader.className = 'post_header';
    postHeader.innerHTML = `
        <div class="post_id"><span>#${postId}</span></div>
        <div class="post_time"><span>${timeText}</span></div>
    `;
    
    // 创建帖子内容区域
    const postContent = document.createElement('div');
    postContent.className = 'post_content';
    postContent.innerHTML = `
        ${content}
    `;
    
    // 创建分隔线（用于分隔内容和底部信息）
    const banner = document.createElement('div');
    banner.className = 'banner';
    
    // 创建帖子底部区域（包含点赞和评论信息）
    const postBottom = document.createElement('div');
    postBottom.className = 'post_bottom';
    postBottom.innerHTML = `
        <div class="like"><img src="./img/like.png" /><span>${likes}</span></div>
        <div class="message"><img src="./img/message.png" /><span>${messages}</span></div>
    `;
    
    // 将所有创建的元素按顺序添加到帖子容器中
    postContainer.appendChild(postHeader);
    postContainer.appendChild(postContent);
    postContainer.appendChild(banner);
    postContainer.appendChild(postBottom);
    
    // 获取帖子列表容器并将新帖子插入到列表最前面
    const postList = document.querySelector('.post_list');
    postList.insertBefore(postContainer, postList.firstChild);
}

/**
 * 删除指定ID的帖子
 * @param {string} postId - 要删除的帖子ID
 */
function removePostContainer(postId) {
    // 获取所有帖子元素
    const posts = document.querySelectorAll('.post_container');
    // 遍历所有帖子，找到匹配ID的帖子并删除
    posts.forEach(post => {
        const id = post.querySelector('.post_id span').textContent.slice(1); // 移除#号
        if (id === postId) {
            post.remove();
        }
    });
}

// 创建示例帖子
// createPostContainer("1", "1分钟之前", "问问大家去哪里补办学生卡？", 10, 2)
// createPostContainer("2", "2小时之前", "分享一下实习经验~", 5, 7)

// ===== 发帖功能相关 =====
// 获取发帖表单和输入框元素
// const intputForm = document.getElementById("input_form")
// const inputTextarea = document.getElementById("input_textarea")

// // 添加表单提交事件监听器
// intputForm.addEventListener("submit", function(event) {
//     event.preventDefault(); // 阻止表单的默认提交行为
    
//     // 获取并清理输入内容
//     const post_content = inputTextarea.value.trim();
//     // 如果内容为空，直接返回
//     if(post_content.length === 0 || post_content === null){
//         return;
//     }

//     // 生成新帖子的ID（当前帖子数量 + 1）
//     const posts = document.querySelectorAll('.post_container');
//     let post_id = posts.length + 1;
    
//     // 创建新帖子并添加到列表中
//     createPostContainer(post_id, "刚刚", post_content, 0, 0);
//     // 清空输入框
//     inputTextarea.value = "";
// })
